@@ -1,3 +1,4 @@
+# pylint: disable=missing-docstring
 __all__ = [
     'OnnxNot',
     'OnnxLogical',
@@ -6,7 +7,6 @@ __all__ = [
 from typing import Optional
 
 import torch
-import torch._C as torch_C
 from torch import nn
 
 from onnx2torch.node_converters.registry import add_converter
@@ -16,7 +16,7 @@ from onnx2torch.utils.common import OnnxToTorchModule
 from onnx2torch.utils.common import OperationConverterResult
 from onnx2torch.utils.common import old_style_broadcast
 from onnx2torch.utils.common import onnx_mapping_from_node
-from onnx2torch.utils.custom_export_to_onnx import CustomExportToOnnx
+from onnx2torch.utils.custom_export_to_onnx import DefaultExportToOnnx
 from onnx2torch.utils.custom_export_to_onnx import OnnxToTorchModuleWithCustomExport
 
 _TORCH_FUNCTION_FROM_ONNX_TYPE = {
@@ -26,22 +26,18 @@ _TORCH_FUNCTION_FROM_ONNX_TYPE = {
 }
 
 
-class OnnxNot(nn.Module, OnnxToTorchModuleWithCustomExport):  # pylint: disable=missing-class-docstring
-    def forward(self, input_tensor: torch.Tensor) -> torch.Tensor:  # pylint: disable=missing-function-docstring
-        forward_lambda = lambda: torch.logical_not(input_tensor)
+class OnnxNot(nn.Module, OnnxToTorchModuleWithCustomExport):
+    def forward(self, input_tensor: torch.Tensor) -> torch.Tensor:
+        def _forward() -> torch.Tensor:
+            return torch.logical_not(input_tensor)
+
         if torch.onnx.is_in_onnx_export():
-            return _NotExportToOnnx.set_forward_and_apply(forward_lambda, input_tensor)
+            return DefaultExportToOnnx.export(_forward, 'Not', input_tensor, {})
 
-        return forward_lambda()
+        return _forward()
 
 
-class _NotExportToOnnx(CustomExportToOnnx):  # pylint: disable=abstract-method
-    @staticmethod
-    def symbolic(graph: torch_C.Graph, *args) -> torch_C.Value:
-        return graph.op('Not', *args, outputs=1)
-
-
-class OnnxLogical(nn.Module, OnnxToTorchModule):  # pylint: disable=missing-class-docstring
+class OnnxLogical(nn.Module, OnnxToTorchModule):
     def __init__(self, operation_type: str, broadcast: Optional[int] = None, axis: Optional[int] = None):
         super().__init__()
         self.broadcast = broadcast
@@ -49,9 +45,7 @@ class OnnxLogical(nn.Module, OnnxToTorchModule):  # pylint: disable=missing-clas
 
         self.logic_op_function = _TORCH_FUNCTION_FROM_ONNX_TYPE[operation_type]
 
-    def forward(  # pylint: disable=missing-function-docstring
-        self, first_tensor: torch.Tensor, second_tensor: torch.Tensor
-    ):
+    def forward(self, first_tensor: torch.Tensor, second_tensor: torch.Tensor):
         if self.broadcast == 1 and self.axis is not None:
             second_tensor = old_style_broadcast(first_tensor, second_tensor, self.axis)
 
@@ -64,7 +58,8 @@ class OnnxLogical(nn.Module, OnnxToTorchModule):  # pylint: disable=missing-clas
 @add_converter(operation_type='And', version=7)
 @add_converter(operation_type='Or', version=1)
 @add_converter(operation_type='Or', version=7)
-def _(node: OnnxNode, graph: OnnxGraph) -> OperationConverterResult:  # pylint: disable=unused-argument
+def _(node: OnnxNode, graph: OnnxGraph) -> OperationConverterResult:
+    del graph
     return OperationConverterResult(
         torch_module=OnnxLogical(
             operation_type=node.operation_type,
@@ -76,7 +71,8 @@ def _(node: OnnxNode, graph: OnnxGraph) -> OperationConverterResult:  # pylint:
 
 
 @add_converter(operation_type='Not', version=1)
-def _(node: OnnxNode, graph: OnnxGraph) -> OperationConverterResult:  # pylint: disable=unused-argument
+def _(node: OnnxNode, graph: OnnxGraph) -> OperationConverterResult:
+    del graph
     return OperationConverterResult(
         torch_module=OnnxNot(),
         onnx_mapping=onnx_mapping_from_node(node=node),
