@@ -1,3 +1,4 @@
+# pylint: disable=missing-class-docstring
 __all__ = [
     'OnnxReduceSumDynamicAxes',
     'OnnxReduceSumStaticAxes',
@@ -6,13 +7,14 @@ __all__ = [
 
 from functools import partial
 from typing import Any
+from typing import Dict
 from typing import List
 from typing import Optional
 from typing import Tuple
 from typing import Union
+from typing import cast
 
 import torch
-import torch._C as torch_C
 from torch import nn
 
 from onnx2torch.node_converters.registry import add_converter
@@ -22,20 +24,24 @@ from onnx2torch.utils.common import OnnxMapping
 from onnx2torch.utils.common import OnnxToTorchModule
 from onnx2torch.utils.common import OperationConverterResult
 from onnx2torch.utils.common import get_const_value
+from onnx2torch.utils.common import get_onnx_version
 from onnx2torch.utils.common import onnx_mapping_from_node
-from onnx2torch.utils.custom_export_to_onnx import CustomExportToOnnx
+from onnx2torch.utils.custom_export_to_onnx import DefaultExportToOnnx
 from onnx2torch.utils.custom_export_to_onnx import OnnxToTorchModuleWithCustomExport
 
 
 @torch.fx.wrap
-def _get_element(x: Union[List, Tuple], index: int = 0) -> Any:
+def _get_element(x: Any, index: int = 0) -> Any:
     if isinstance(x, (tuple, list)):
         return x[index]
 
     return x
 
 
-def _initialize_none_dim(dim: Optional[Union[int, Tuple[int, ...]]], input_dim: int):
+def _initialize_none_dim(
+    dim: Optional[Union[int, Tuple[int, ...]]],
+    input_dim: int,
+) -> Union[List[int], Tuple[int, ...], int]:
     if dim is None:
         return list(range(input_dim))
 
@@ -46,27 +52,27 @@ def _log_sum(
     input_tensor: torch.Tensor,
     dim: Optional[Union[int, Tuple[int, ...]]] = None,
     keepdim: bool = False,
-):
-    dim = _initialize_none_dim(dim, input_tensor.dim())
-    return torch.log(torch.sum(input_tensor, dim=dim, keepdim=keepdim))
+) -> torch.Tensor:
+    dim_ = _initialize_none_dim(dim, input_tensor.dim())
+    return torch.log(torch.sum(input_tensor, dim=dim_, keepdim=keepdim))
 
 
 def _log_sum_exp(
     input_tensor: torch.Tensor,
     dim: Optional[Union[int, Tuple[int, ...]]] = None,
     keepdim: bool = False,
-):
-    dim = _initialize_none_dim(dim, input_tensor.dim())
-    return torch.logsumexp(input_tensor, dim=dim, keepdim=keepdim)
+) -> torch.Tensor:
+    dim_ = _initialize_none_dim(dim, input_tensor.dim())
+    return torch.logsumexp(input_tensor, dim=dim_, keepdim=keepdim)
 
 
 def _sum_square(
     input_tensor: torch.Tensor,
     dim: Optional[Union[int, Tuple[int, ...]]] = None,
     keepdim: bool = False,
-):
-    dim = _initialize_none_dim(dim, input_tensor.dim())
-    return torch.sum(torch.square(input_tensor), dim=dim, keepdim=keepdim)
+) -> torch.Tensor:
+    dim_ = _initialize_none_dim(dim, input_tensor.dim())
+    return torch.sum(torch.square(input_tensor), dim=dim_, keepdim=keepdim)
 
 
 _TORCH_FUNCTION_FROM_ONNX_TYPE = {
@@ -83,64 +89,51 @@ _TORCH_FUNCTION_FROM_ONNX_TYPE = {
 }
 
 
-class OnnxReduceSumDynamicAxes(  # pylint: disable=missing-class-docstring
-    nn.Module,
-    OnnxToTorchModuleWithCustomExport,
-):
+class OnnxReduceSumDynamicAxes(nn.Module, OnnxToTorchModuleWithCustomExport):
     def __init__(self, keepdims: int = 1, noop_with_empty_axes: int = 0):
         super().__init__()
 
-        self.keepdims = keepdims == 1
-        self.noop_with_empty_axes = noop_with_empty_axes == 1
+        self._keepdims = keepdims
+        self._noop_with_empty_axes = noop_with_empty_axes
+
+    def _onnx_attrs(self, opset_version: int) -> Dict[str, Any]:
+        del opset_version
+        return {
+            'noop_with_empty_axes_i': self._noop_with_empty_axes,
+            'keepdims_i': self._keepdims,
+        }
 
     def forward(  # pylint: disable=missing-function-docstring
         self,
         input_tensor: torch.Tensor,
         axes: Optional[torch.Tensor] = None,
     ) -> torch.Tensor:
-        def _forward():
+        def _forward() -> torch.Tensor:
             if axes is None or axes.nelement() == 0:
-                if self.noop_with_empty_axes:
+                if self._noop_with_empty_axes:
                     return input_tensor
 
-                if not self.keepdims:
+                if not self._keepdims:
                     return torch.sum(input_tensor)
 
                 fixed_axes = list(range(input_tensor.dim()))
             else:
                 fixed_axes = torch.sort(axes).values.tolist()
 
-            return torch.sum(input_tensor, dim=fixed_axes, keepdim=self.keepdims)
+            return torch.sum(input_tensor, dim=fixed_axes, keepdim=bool(self._keepdims))
 
         if torch.onnx.is_in_onnx_export():
             args = [input_tensor]
             if axes is not None:
                 args.append(axes)
 
-            return _ReduceSumExportToOnnx.set_forward_and_apply(
-                _forward,
-                *args,
-                int(self.keepdims),
-                int(self.noop_with_empty_axes),
-            )
+            onnx_attrs = self._onnx_attrs(opset_version=get_onnx_version())
+            return DefaultExportToOnnx.export(_forward, 'ReduceSum', *args, onnx_attrs)
 
         return _forward()
 
 
-class _ReduceSumExportToOnnx(CustomExportToOnnx):  # pylint: disable=abstract-method
-    @staticmethod
-    def symbolic(graph: torch_C.Graph, *args) -> torch_C.Value:
-        *args, keepdims, noop_with_empty_axes = args
-        return graph.op(
-            'ReduceSum',
-            *args,
-            noop_with_empty_axes_i=noop_with_empty_axes,
-            keepdims_i=keepdims,
-            outputs=1,
-        )
-
-
-class OnnxReduceSumStaticAxes(nn.Module, OnnxToTorchModule):  # pylint: disable=missing-class-docstring
+class OnnxReduceSumStaticAxes(nn.Module, OnnxToTorchModule):
     def __init__(
         self,
         axes: List[int],
@@ -151,28 +144,28 @@ class OnnxReduceSumStaticAxes(nn.Module, OnnxToTorchModule):  # pylint: disable=
         if axes is not None:
             axes = sorted(axes)
 
-        self.keepdims = keepdims == 1
-        self.noop_with_empty_axes = noop_with_empty_axes == 1
-        self.axes = axes
+        self._keepdims = keepdims
+        self._noop_with_empty_axes = noop_with_empty_axes
+        self._axes = axes
 
     def forward(self, input_tensor: torch.Tensor) -> torch.Tensor:  # pylint: disable=missing-function-docstring
-        if self.axes is None or len(self.axes) == 0:
-            if self.noop_with_empty_axes:
+        if self._axes is None or len(self._axes) == 0:
+            if self._noop_with_empty_axes:
                 return input_tensor
 
-            if not self.keepdims:
+            if not self._keepdims:
                 return self.math_op_function(input_tensor)
 
-            self.axes = list(range(input_tensor.dim()))
+            self._axes = list(range(input_tensor.dim()))
 
-        return torch.sum(input_tensor, dim=self.axes, keepdim=self.keepdims)
+        return torch.sum(input_tensor, dim=self._axes, keepdim=bool(self._keepdims))
 
 
-class OnnxReduceStaticAxes(nn.Module, OnnxToTorchModule):  # pylint: disable=missing-class-docstring
+class OnnxReduceStaticAxes(nn.Module, OnnxToTorchModule):
     def __init__(
         self,
         operation_type: str,
-        axes: List[int],
+        axes: Optional[List[int]],
         keepdims: int = 1,
     ):
         super().__init__()
@@ -238,10 +231,11 @@ class OnnxReduceStaticAxes(nn.Module, OnnxToTorchModule):  # pylint: disable=mis
 @add_converter(operation_type='ReduceSumSquare', version=1)
 @add_converter(operation_type='ReduceSumSquare', version=11)
 @add_converter(operation_type='ReduceSumSquare', version=13)
-def _(node: OnnxNode, graph: OnnxGraph) -> OperationConverterResult:  # pylint: disable=unused-argument
+def _(node: OnnxNode, graph: OnnxGraph) -> OperationConverterResult:
+    del graph
     node_attributes = node.attributes
-    axes = node_attributes.get('axes', None)
-    keepdims = node_attributes.get('keepdims', 1)
+    axes: Optional[List[int]] = node_attributes.get('axes', None)
+    keepdims: int = node_attributes.get('keepdims', 1)
 
     return OperationConverterResult(
         torch_module=OnnxReduceStaticAxes(
@@ -254,13 +248,13 @@ def _(node: OnnxNode, graph: OnnxGraph) -> OperationConverterResult:  # pylint:
 
 
 @add_converter(operation_type='ReduceSum', version=13)
-def _(node: OnnxNode, graph: OnnxGraph) -> OperationConverterResult:  # pylint: disable=unused-argument
-    keepdims = node.attributes.get('keepdims', 1)
-    noop_with_empty_axes = node.attributes.get('noop_with_empty_axes', 0)
+def _(node: OnnxNode, graph: OnnxGraph) -> OperationConverterResult:
+    keepdims: int = node.attributes.get('keepdims', 1)
+    noop_with_empty_axes: int = node.attributes.get('noop_with_empty_axes', 0)
 
     if len(node.input_values) == 2:
         try:
-            axes = get_const_value(node.input_values[1], graph)
+            axes = cast(torch.Tensor, get_const_value(node.input_values[1], graph))
             axes = axes.tolist()
             return OperationConverterResult(
                 torch_module=OnnxReduceSumStaticAxes(
